@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-search-dialog.c 5786 2007-08-12 12:36:30Z vgeddes $
+ * $Id: gedit-search-dialog.c 6948 2009-03-04 16:53:06Z icq $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,6 +40,7 @@
 #include "gedit-history-entry.h"
 #include "gedit-utils.h"
 #include "gedit-marshal.h"
+#include "gedit-dirs.h"
 
 #define GEDIT_SEARCH_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
 						GEDIT_TYPE_SEARCH_DIALOG,              \
@@ -73,7 +74,7 @@ struct _GeditSearchDialogPrivate
 	GtkWidget *replace_button;
 	GtkWidget *replace_all_button;
 
-	gboolean   glade_error;
+	gboolean   ui_error;
 };
 
 G_DEFINE_TYPE(GeditSearchDialog, gedit_search_dialog, GTK_TYPE_DIALOG)
@@ -217,14 +218,12 @@ insert_text_handler (GtkEditable *editable,
 }
 
 static void
-search_entry_changed (GtkComboBox       *combo,
-		      GeditSearchDialog *dialog)
+search_text_entry_changed (GtkEditable       *editable,
+			   GeditSearchDialog *dialog)
 {
-	GtkWidget *entry;
 	const gchar *search_string;
 
-	entry = gtk_bin_get_child (GTK_BIN (combo));
-	search_string = gtk_entry_get_text (GTK_ENTRY (entry));
+	search_string = gtk_entry_get_text (GTK_ENTRY (editable));
 	g_return_if_fail (search_string != NULL);
 
 	if (*search_string != '\0')
@@ -258,16 +257,30 @@ response_handler (GeditSearchDialog *dialog,
 		case GEDIT_SEARCH_DIALOG_REPLACE_ALL_RESPONSE:
 			str = gtk_entry_get_text (GTK_ENTRY (dialog->priv->replace_text_entry));
 			if (*str != '\0')
+			{
+				gchar *text;
+
+				text = gedit_utils_unescape_search_text (str);
 				gedit_history_entry_prepend_text
 						(GEDIT_HISTORY_ENTRY (dialog->priv->replace_entry),
-						 str);
+						 text);
+
+				g_free (text);
+			}
 			/* fall through, so that we also save the find entry */
 		case GEDIT_SEARCH_DIALOG_FIND_RESPONSE:
 			str = gtk_entry_get_text (GTK_ENTRY (dialog->priv->search_text_entry));
 			if (*str != '\0')
+			{
+				gchar *text;
+
+				text = gedit_utils_unescape_search_text (str);
 				gedit_history_entry_prepend_text
 						(GEDIT_HISTORY_ENTRY (dialog->priv->search_entry),
-						 str);
+						 text);
+
+				g_free (text);
+			}
 	}
 }
 
@@ -307,6 +320,11 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 	GtkWidget *content;
 	GtkWidget *error_widget;
 	gboolean ret;
+	gchar *file;
+	gchar *root_objects[] = {
+		"search_dialog_content",
+		NULL
+	};
 
 	dlg->priv = GEDIT_SEARCH_DIALOG_GET_PRIVATE (dlg);
 
@@ -324,18 +342,20 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->action_area), 5);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->action_area), 6);
 
-	ret = gedit_utils_get_glade_widgets (GEDIT_GLADEDIR "gedit-search-dialog.glade",
-					     "search_dialog_content",
-					     &error_widget,
-					     "search_dialog_content", &content,
-					     "table", &dlg->priv->table,
-					     "search_label", &dlg->priv->search_label,
-					     "replace_with_label", &dlg->priv->replace_label,
-					     "match_case_checkbutton", &dlg->priv->match_case_checkbutton,
-					     "entire_word_checkbutton", &dlg->priv->entire_word_checkbutton,
-					     "search_backwards_checkbutton", &dlg->priv->backwards_checkbutton,
-					     "wrap_around_checkbutton", &dlg->priv->wrap_around_checkbutton,
-					     NULL);
+	file = gedit_dirs_get_ui_file ("gedit-search-dialog.ui");
+	ret = gedit_utils_get_ui_objects (file,
+					  root_objects,
+					  &error_widget,
+					  "search_dialog_content", &content,
+					  "table", &dlg->priv->table,
+					  "search_label", &dlg->priv->search_label,
+					  "replace_with_label", &dlg->priv->replace_label,
+					  "match_case_checkbutton", &dlg->priv->match_case_checkbutton,
+					  "entire_word_checkbutton", &dlg->priv->entire_word_checkbutton,
+					  "search_backwards_checkbutton", &dlg->priv->backwards_checkbutton,
+					  "wrap_around_checkbutton", &dlg->priv->wrap_around_checkbutton,
+					  NULL);
+	g_free (file);
 
 	if (!ret)
 	{
@@ -345,7 +365,7 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 					     error_widget);
 		gtk_container_set_border_width (GTK_CONTAINER (error_widget), 5);					     
 
-		dlg->priv->glade_error = TRUE;
+		dlg->priv->ui_error = TRUE;
 
 		return;
 	}
@@ -353,6 +373,10 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 	dlg->priv->search_entry = gedit_history_entry_new ("gedit2_search_for_entry",
 							   TRUE);
 	gtk_widget_set_size_request (dlg->priv->search_entry, 300, -1);
+	gedit_history_entry_set_escape_func
+			(GEDIT_HISTORY_ENTRY (dlg->priv->search_entry),
+			 (GeditHistoryEntryEscapeFunc) gedit_utils_escape_search_text);
+
 	dlg->priv->search_text_entry = gedit_history_entry_get_entry
 			(GEDIT_HISTORY_ENTRY (dlg->priv->search_entry));
 	gtk_entry_set_activates_default (GTK_ENTRY (dlg->priv->search_text_entry),
@@ -364,6 +388,10 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 
 	dlg->priv->replace_entry = gedit_history_entry_new ("gedit2_replace_with_entry",
 							    TRUE);
+	gedit_history_entry_set_escape_func
+			(GEDIT_HISTORY_ENTRY (dlg->priv->replace_entry),
+			 (GeditHistoryEntryEscapeFunc) gedit_utils_escape_search_text);
+
 	dlg->priv->replace_text_entry = gedit_history_entry_get_entry
 			(GEDIT_HISTORY_ENTRY (dlg->priv->replace_entry));
 	gtk_entry_set_activates_default (GTK_ENTRY (dlg->priv->replace_text_entry),
@@ -412,7 +440,8 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
 			    content, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (content), 5);	     
+	g_object_unref (content);
+	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
 
 	g_signal_connect (dlg->priv->search_text_entry,
 			  "insert_text",
@@ -422,9 +451,9 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 			  "insert_text",
 			  G_CALLBACK (insert_text_handler),
 			  NULL);
-	g_signal_connect (dlg->priv->search_entry,
+	g_signal_connect (dlg->priv->search_text_entry,
 			  "changed",
-			  G_CALLBACK (search_entry_changed),
+			  G_CALLBACK (search_text_entry_changed),
 			  dlg);
 
 	g_signal_connect (dlg,
@@ -464,7 +493,7 @@ gedit_search_dialog_set_show_replace (GeditSearchDialog *dialog,
 {
 	g_return_if_fail (GEDIT_IS_SEARCH_DIALOG (dialog));
 
-	if (dialog->priv->glade_error)
+	if (dialog->priv->ui_error)
 		return;
 
 	dialog->priv->show_replace = show_replace != FALSE;
