@@ -3,7 +3,7 @@
  * gedit-metadata-manager.c
  * This file is part of gedit
  *
- * Copyright (C) 2003  Paolo Maggi 
+ * Copyright (C) 2003-2007  Paolo Maggi 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  */
  
 /*
- * Modified by the gedit Team, 2003. See the AUTHORS file for a 
+ * Modified by the gedit Team, 2003-2007. See the AUTHORS file for a 
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  */
@@ -33,14 +33,14 @@
 
 #include <time.h>
 #include <stdlib.h>
-
 #include <libxml/xmlreader.h>
-
-#include <libgnome/gnome-util.h>
-
 #include "gedit-metadata-manager.h"
 #include "gedit-debug.h"
+#include "gedit-dirs.h"
 
+/*
+#define GEDIT_METADATA_VERBOSE_DEBUG	1
+*/
 
 #define METADATA_FILE 	"gedit-metadata.xml"
 
@@ -79,7 +79,9 @@ item_free (gpointer data)
 	
 	g_return_if_fail (data != NULL);
 
+#ifdef GEDIT_METADATA_VERBOSE_DEBUG
 	gedit_debug (DEBUG_METADATA);
+#endif
 
 	item = (Item *)data;
 
@@ -92,14 +94,15 @@ item_free (gpointer data)
 static void
 gedit_metadata_manager_arm_timeout (void)
 {
-	if (gedit_metadata_manager->timeout_id)
-		return;
-	gedit_metadata_manager->timeout_id = 
-		g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE,
-				    2000, /* 2 sec */
-				    (GSourceFunc)gedit_metadata_manager_save,
-				    NULL,
-				    NULL);
+	if (gedit_metadata_manager->timeout_id == 0)
+	{
+		gedit_metadata_manager->timeout_id = 
+			g_timeout_add_seconds_full (G_PRIORITY_DEFAULT_IDLE,
+						    2,
+						    (GSourceFunc)gedit_metadata_manager_save,
+						    NULL,
+						    NULL);
+	}
 }
 
 static gboolean
@@ -154,7 +157,9 @@ parseItem (xmlDocPtr doc, xmlNodePtr cur)
 	xmlChar *uri;
 	xmlChar *atime;
 	
+#ifdef GEDIT_METADATA_VERBOSE_DEBUG
 	gedit_debug (DEBUG_METADATA);
+#endif	
 
 	if (xmlStrcmp (cur->name, (const xmlChar *)"document") != 0)
 			return;
@@ -213,6 +218,23 @@ parseItem (xmlDocPtr doc, xmlNodePtr cur)
 	xmlFree (atime);
 }
 
+static gchar *
+get_metadata_filename (void)
+{
+	gchar *cache_dir;
+	gchar *metadata;
+
+	cache_dir = gedit_dirs_get_user_cache_dir ();
+
+	metadata = g_build_filename (cache_dir,
+				     METADATA_FILE,
+				     NULL);
+
+	g_free (cache_dir);
+
+	return metadata;
+}
+
 static gboolean
 load_values ()
 {
@@ -230,8 +252,9 @@ load_values ()
 	xmlKeepBlanksDefault (0);
 
 	/* FIXME: file locking - Paolo */
-	file_name = gnome_util_home_file (METADATA_FILE);
-	if (!g_file_test (file_name, G_FILE_TEST_EXISTS))
+	file_name = get_metadata_filename ();
+	if ((file_name == NULL) ||
+	    (!g_file_test (file_name, G_FILE_TEST_EXISTS)))
 	{
 		g_free (file_name);
 		return FALSE;
@@ -284,13 +307,12 @@ gedit_metadata_manager_get (const gchar *uri,
 	Item *item;
 	gchar *value;
 
-	gedit_debug (DEBUG_METADATA);
-
 	g_return_val_if_fail (uri != NULL, NULL);
 	g_return_val_if_fail (key != NULL, NULL);
 
-	if (gedit_metadata_manager == NULL)
-		gedit_metadata_manager_init ();
+	gedit_debug_message (DEBUG_METADATA, "URI: %s --- key: %s", uri, key );
+
+	gedit_metadata_manager_init ();
 
 	if (!gedit_metadata_manager->values_loaded)
 	{
@@ -328,13 +350,12 @@ gedit_metadata_manager_set (const gchar *uri,
 {
 	Item *item;
 
-	gedit_debug (DEBUG_METADATA);
-
 	g_return_if_fail (uri != NULL);
 	g_return_if_fail (key != NULL);
 
-	if (gedit_metadata_manager == NULL)
-		gedit_metadata_manager_init ();
+	gedit_debug_message (DEBUG_METADATA, "URI: %s --- key: %s --- value: %s", uri, key, value);
+	
+	gedit_metadata_manager_init ();
 
 	if (!gedit_metadata_manager->values_loaded)
 	{
@@ -381,7 +402,9 @@ save_values (const gchar *key, const gchar *value, xmlNodePtr parent)
 {
 	xmlNodePtr xml_node;
 
+#ifdef GEDIT_METADATA_VERBOSE_DEBUG
 	gedit_debug (DEBUG_METADATA);
+#endif	
 
 	g_return_if_fail (key != NULL);
 	
@@ -400,7 +423,9 @@ save_values (const gchar *key, const gchar *value, xmlNodePtr parent)
 		    (const xmlChar *)"value",
 		    (const xmlChar *)value);
 
+#ifdef GEDIT_METADATA_VERBOSE_DEBUG
 	gedit_debug_message (DEBUG_METADATA, "entry: %s = %s", key, value);
+#endif	
 }
 
 static void
@@ -410,7 +435,9 @@ save_item (const gchar *key, const gpointer *data, xmlNodePtr parent)
 	const Item *item = (const Item *)data;
 	gchar *atime;
 
+#ifdef GEDIT_METADATA_VERBOSE_DEBUG
 	gedit_debug (DEBUG_METADATA);
+#endif
 
 	g_return_if_fail (key != NULL);
 
@@ -421,12 +448,16 @@ save_item (const gchar *key, const gpointer *data, xmlNodePtr parent)
 
 	xmlSetProp (xml_node, (const xmlChar *)"uri", (const xmlChar *)key);
 
+#ifdef GEDIT_METADATA_VERBOSE_DEBUG
 	gedit_debug_message (DEBUG_METADATA, "uri: %s", key);
+#endif	
 
 	atime = g_strdup_printf ("%ld", item->atime);
 	xmlSetProp (xml_node, (const xmlChar *)"atime", (const xmlChar *)atime);	
 
+#ifdef GEDIT_METADATA_VERBOSE_DEBUG
 	gedit_debug_message (DEBUG_METADATA, "atime: %s", atime);
+#endif	
 
 	g_free (atime);
 
@@ -505,9 +536,23 @@ gedit_metadata_manager_save (gpointer data)
 			      root);        
 
 	/* FIXME: lock file - Paolo */
-	file_name = gnome_util_home_file (METADATA_FILE);
-	xmlSaveFormatFile (file_name, doc, 1);
-	g_free (file_name);
+	file_name = get_metadata_filename ();
+	if (file_name != NULL)
+	{
+		gchar *cache_dir;
+		int res;
+
+		/* make sure the cache dir exists */
+		cache_dir = gedit_dirs_get_user_cache_dir ();
+		res = g_mkdir_with_parents (cache_dir, 0755);
+		if (res != -1)
+		{
+			xmlSaveFormatFile (file_name, doc, 1);
+		}
+
+		g_free (cache_dir);
+		g_free (file_name);
+	}
 
 	xmlFreeDoc (doc); 
 
