@@ -71,7 +71,7 @@ dialog_response_handler (GtkDialog *dlg,
 	if (res_id == GTK_RESPONSE_HELP)
 	{
 		gedit_help_display (GTK_WINDOW (dlg),
-				    "gedit.xml",
+				    NULL,
 				    "gedit-spell-checker-plugin");
 
 		g_signal_stop_emission_by_name (dlg, "response");
@@ -115,14 +115,20 @@ language_row_activated (GtkTreeView *tree_view,
 }
 
 static void
-gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
+create_dialog (GeditSpellLanguageDialog *dlg,
+	       const gchar *data_dir)
 {
 	GtkWidget *error_widget;
 	GtkWidget *content;
 	gboolean ret;
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *column;
-
+	gchar *ui_file;
+	gchar *root_objects[] = {
+		"content",
+		NULL
+	};
+	
 	gtk_dialog_add_buttons (GTK_DIALOG (dlg),
 				GTK_STOCK_CANCEL,
 				GTK_RESPONSE_CANCEL,
@@ -148,13 +154,15 @@ gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
 			  G_CALLBACK (dialog_response_handler),
 			  NULL);
 
-	ret = gedit_utils_get_glade_widgets (GEDIT_GLADEDIR "languages-dialog.glade2",
-					     "content",
-					     &error_widget,
-					     "content", &content,
-					     "languages_treeview", &dlg->languages_treeview,
-					     NULL);
-
+	ui_file = g_build_filename (data_dir, "languages-dialog.ui", NULL);
+	ret = gedit_utils_get_ui_objects (ui_file,
+					  root_objects,	
+					  &error_widget,
+					  "content", &content,
+					  "languages_treeview", &dlg->languages_treeview,
+					  NULL);
+	g_free (ui_file);
+	
 	if (!ret)
 	{
 		gtk_widget_show (error_widget);
@@ -167,7 +175,7 @@ gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
 			    content, TRUE, TRUE, 0);
-
+	g_object_unref (content);
 	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
 
 	dlg->model = GTK_TREE_MODEL (gtk_list_store_new (ENCODING_NUM_COLS,
@@ -203,6 +211,12 @@ gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
 			  dlg);
 }
 
+static void
+gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
+{
+	
+}
+
 static void
 populate_language_list (GeditSpellLanguageDialog        *dlg,
 			const GeditSpellCheckerLanguage *cur_lang)
@@ -245,7 +259,8 @@ populate_language_list (GeditSpellLanguageDialog        *dlg,
 
 GtkWidget *
 gedit_spell_language_dialog_new (GtkWindow                       *parent,
-				 const GeditSpellCheckerLanguage *cur_lang)
+				 const GeditSpellCheckerLanguage *cur_lang,
+				 const gchar *data_dir)
 {
 	GeditSpellLanguageDialog *dlg;
 
@@ -253,6 +268,8 @@ gedit_spell_language_dialog_new (GtkWindow                       *parent,
 
 	dlg = g_object_new (GEDIT_TYPE_SPELL_LANGUAGE_DIALOG, NULL);
 
+	create_dialog (dlg, data_dir);
+
 	populate_language_list (dlg, cur_lang);
 
 	gtk_window_set_transient_for (GTK_WINDOW (dlg), parent);
